summaryrefslogtreecommitdiff
path: root/scripts/build/libc/uClibc.sh
diff options
context:
space:
mode:
authorYann E. MORIN" <yann.morin.1998@anciens.enib.fr>2011-01-22 21:35:43 (GMT)
committerYann E. MORIN" <yann.morin.1998@anciens.enib.fr>2011-01-22 21:35:43 (GMT)
commit49ab32ffe2c0da1e7d6dcbb10e29f9b95a97ca2c (patch)
treedd439ce1b23044cd0c546c54e900abdce4d206c1 /scripts/build/libc/uClibc.sh
parentb343b0216b476129b1117f20d1f642b6d86e358f (diff)
scripts: PARALLELMFLAGS is evil, rename
The reunification of the glibc/eglibc code paths exposed a nasty bug in the glibc build: use of PARALLELMFLAGS breaks the build. See the explanations in that bug report against FC6: https://bugzilla.redhat.com/show_bug.cgi?format=multiple&id=212111 Signed-off-by: "Yann E. MORIN" <yann.morin.1998@anciens.enib.fr>
Diffstat (limited to 'scripts/build/libc/uClibc.sh')
-rw-r--r--scripts/build/libc/uClibc.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/scripts/build/libc/uClibc.sh b/scripts/build/libc/uClibc.sh
index f4a84b8..a164979 100644
--- a/scripts/build/libc/uClibc.sh
+++ b/scripts/build/libc/uClibc.sh
@@ -138,7 +138,7 @@ do_libc_start_files() {
if [ "${CT_THREADS}" = "nptl" ]; then
CT_DoLog EXTRA "Building start files"
CT_DoExecLog ALL \
- make ${CT_LIBC_UCLIBC_PARALLEL:+${PARALLELMFLAGS}} \
+ make ${CT_LIBC_UCLIBC_PARALLEL:+${JOBSFLAGS}} \
CROSS="${cross}" \
PREFIX="${CT_SYSROOT_DIR}/" \
STRIPTOOL=true \
@@ -208,7 +208,7 @@ do_libc() {
LOCALE_DATA_FILENAME="${uclibc_local_tarball}.tgz" \
pregen
CT_DoExecLog ALL \
- make ${CT_LIBC_UCLIBC_PARALLEL:+${PARALLELMFLAGS}} \
+ make ${CT_LIBC_UCLIBC_PARALLEL:+${JOBSFLAGS}} \
CROSS=${CT_TARGET}- \
PREFIX="${CT_SYSROOT_DIR}/" \
STRIPTOOL=true \
@@ -228,7 +228,7 @@ do_libc() {
# We do _not_ want to strip anything for now, in case we specifically
# asked for a debug toolchain, hence the STRIPTOOL= assignment
#
# Note: PARALLELMFLAGS is not usefull for installation.
#
CT_DoLog EXTRA "Installing C library"
CT_DoExecLog ALL \
@@ -228,7 +228,7 @@ do_libc() {
# asked for a debug toolchain, hence the STRIPTOOL= assignment
#
- # Note: PARALLELMFLAGS is not usefull for installation.
+ # Note: JOBSFLAGS is not usefull for installation.
#
CT_DoLog EXTRA "Installing C library"